@@ -29,13 +29,12 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
 
 namespace Gwenview
 {
-
 namespace MouseWheelBehavior
 {
 enum Enum {
     Scroll,
     Browse,
-    Zoom
+    Zoom,
 };
 
 } // namespace MouseWheelBehavior
